.TH vncserver 1 "31 March 2005" "RealVNC Ltd" "Virtual Network Computing"
.SH NAME
vncserver \- start or stop a VNC server
.SH SYNOPSIS
.B vncserver
.RI [: display ]
.RB [ -config
.IR config-file ]
.RI [ options... ]
.br
.BI "vncserver \-kill :" display
.br
.B vncserver \-help
.br
.B vncserver \-list
.br
.B vncserver \-test
.SH DESCRIPTION
.B vncserver
is used to start or stop a VNC (Virtual Network Computing) desktop. It
is a configurable and user-friendly front-end to the Xvnc(1) command.
.SH OPTIONS
.B vncserver
can be run with no options. In this case it will choose the first
available display number (usually :1), read the system configuration
file from
.IR /etc/vnc/config ,
read the user's configuration file from
.I $HOME/.vnc/config
and start a VNC desktop configured appropriately. Alternatively, the
following options can be specified on the command-line.
.TP
.B :\fIdisplay\fP
Start a VNC desktop on the specified display number. If the display is
already in use then
.B vncserver
will print an error message and exit.
.TP
.BI "\-config " config-file
Load
.I config-file
instead of \fI$HOME/.vnc/config\fP. Multiple
.B -config
options can be specified to load more than one configuration file in
the order specified. The system configuration file is always read from
\fI/etc/vnc/config\fP before any other configuration files.
.TP
.B \-kill :\fIdisplay\fP
Shut down the VNC server running on :\fIdisplay\fP.
.TP
.B \-help
Display a list of command-line options.
.TP
.B -list
List the configuration variables.
.TP
.B -test
Test mode. In this mode,
.B vncserver
terminates before starting or stopping any desktops, but after any
validity checks have taken place. In addition, the appropriate
command is printed to standard out. For example, the command-line

.RS 12
.B vncserver
\-test :1 -config
.I myconfig
.RE
.IP
verifies that display :1 is available and checks
.I myconfig
for syntax errors before printing the appropriate Xvnc command-line
and exiting.
.TP
.I options
In addition to these options, any unrecognised command-line options
are passed directly to the Xvnc command. See the
.B COMMAND-LINE PARAMETERS
section for details.
.SH X APPLICATIONS SCRIPT
The
.I $HOME/.vnc/xstartup
script is run by
.B vncserver
and usually specifies a window manager and some applications that are
run by default on any VNC desktops. If this file does not exist then
.B vncserver
attempts to copy the system default from
.IR /etc/vnc/xstartup .
If this fails then a default is created.  The xstartup file can be
edited to change the applications run at startup (but note that this
will not affect an existing desktop).
.SH CONFIGURATION FILES
.B vncserver
allows users to configure their VNC desktops using configuration
files. By default,
.B vncserver
reads in two configuration files each time it is run. The first is the
system configuration file,
.IR /etc/vnc/config ,
and the second is the user's configuration file,
.IR $HOME/.vnc/config .
.P
Each line in a configuration file is a
.I configuration entry
and is used to provide a default value for one of Xvnc's many
command-line parameters. These defaults can be overridden by a
subsequent configuration file or on the
.B vncserver
command-line. Each configuration entry is treated as a command-line
parameter to Xvnc subject to the following transformations:
.RS 4
.IP o 2
Comments are stripped. A comment is introduced using the # character
and extends to the end of the line.
.IP o
Whitespace at the beginning and end of both the parameter name and
its value is stripped.
.IP o
Environment variables of the form $env or ${env} are expanded where
they appear in the parameter value.
.RE
.P
Default values must be specified in the form that would be used on the
command-line. For most parameters this is:

.RS 4
\-\fIname parameters...\fP
.RE
.P
Using this syntax, an option can be given any number of parameters,
including zero. For example, the following are all valid:

.RS 4
\-screen 1 1280x1024x32
.br
\-desktop "My VNC Desktop"
.br
\-UserPasswdVerifier UnixAuth
.br
\-pn
.RE
.P
Some X server options are specified using a leading + instead of a -,
or with no leading character at all. These should be specified in the
form the X server expects them, for example:

.RS 4
+extension
.I name
.br
nologo
.RE
.P
Finally, to turn off VNC options, use the following syntax:

.RS 4
.RI \- name =0
.RE
.P
For example:

.RS 4
-AcceptCutText=0
.RE
.SH COMMAND-LINE PARAMETERS
Anything that can appear in a configuration file can also be specified
on the command-line. When processing command-line parameters,
.B vncserver
attempts to work out how the command-line parameters are grouped into
configuration entries according to the following rules:
.RS 4
.IP o 2
The first unrecognised command-line parameter is treated as the start
of a configuration entry.
.IP o
A command-line parameter that begins with + or - is treated as the start
of a configuration entry.
.IP o
A single - on the command-line denotes the end of a configuration entry.
This is only required if the following command-line parameter is the
start of the next configuration entry but does not begin with + or -.
.IP o
A single + on the command-line indicates that the next command-line
parameter part of the current configuration entry. This is only
required if the next command-line parameter begins with + or -.
.RE
.P
For example, given the following
.B vncserver
command-line:

.RS 4
.B
vncserver
\-desktop "My desktop" nologo
.RE
.P
.B
vncserver
will infer a single configuration entry:

.RS 4
\-desktop "My desktop" nologo
.RE
.P
which is probably not the intended effect. If a - is added to the
command-line as follows:

.RS 4
.B
vncserver
\-desktop "My desktop" \- nologo
.RE
.P
then
.B vncserver
will infer two configuration entries:

.RS 4
-desktop "My desktop"
.br
nologo
.RE
.P
For a detailed list of all the Xvnc command-line options, run
.IP
.BR "vncserver " \-list
.SH ADDITIONAL FILES
For each VNC desktop,
.B vncserver
creates two additional files in \fI$HOME/.vnc\fP:
.TP
\fIhost\fP:\fIdisplay\fP.log 
The log file for the VNC desktop and applications started in
xstartup. If the VNC desktop fails to start then
.B vncserver
prints the contents of this log before exiting.
.TP
\fIhost\fP:\fIdisplay\fP.pid
Contains the process ID of the VNC desktop. This is used by the
.B \-kill
option.
.SH SEE ALSO
.BR vncviewer (1),
.BR vncaddrbook (1),
.BR vncconfig (1),
.BR vncpasswd (1),
.BR vnclicense (1),
.BR vnckeygen (1),
.BR Xvnc (1),
.BR x0vncserver (1),
.BR vncinitconfig (1)
.br
http://www.realvnc.com
.SH AUTHOR
RealVNC Ltd.
